@@ -1,6 +1,5 @@
 import codecs
 from io import BytesIO, StringIO
-import distutils.dir_util
 import xml.etree.ElementTree as ET
 import logging
 import math
@@ -11,19 +10,24 @@ import shutil
 import sys
 import struct
 import subprocess
+import typing
 import zlib
 
+hasClick = False
+hasTqdm = False
+hasGUI = False
+
 try:
     import click
     hasClick = True
 except ImportError:
-    hasClick = False
+    pass
 
 try:
     from tqdm import tqdm
     hasTqdm = True
 except ImportError:
-    hasTqdm = False
+    pass
 
 table = {}
 
@@ -382,30 +386,111 @@ class Stream(object):
         self.f.truncate()
 
 
-# Logging
+# CLI/GUI
 if hasClick:
-    @click.group(no_args_is_help=True)
+    appname = ""
+    appversion = ""
+    datafolder = ""
+    filecheck = ""
+    crc = -1
+
+
+    def setupTool(_appname="", _appversion="", _datafolder="", _filecheck="", _crc=-1):
+        global appname, appversion, datafolder, filecheck, crc
+        appname = _appname
+        appversion = _appversion
+        datafolder = _datafolder
+        filecheck = _filecheck
+        crc = _crc
+        cli()
+
+
+    @click.group(invoke_without_command=True)
     @click.option("--log", is_flag=True, default=False)
-    def cli(log):
-        if log:
-            enableLogging()
+    @click.option("--gui", is_flag=True, default=False)
+    @click.pass_context
+    def cli(ctx, log, gui):
+        setupFileLogging(log)
+        if ctx.invoked_subcommand is None:
+            multi = typing.cast(click.MultiCommand, ctx.command)
+            ctx.invoke(multi.get_command(ctx, "main"), gui=gui)
         else:
-            disableLogging()
+            if not runStartup():
+                quit()
 
 
-def enableLogging():
+    @cli.command(hidden=True)
+    @click.option("--gui", is_flag=True, default=False)
+    def main(gui):
+        if datafolder != "" and not os.path.isdir(datafolder):
+            makeFolder(datafolder)
+        if not gui:
+            runCLI()
+        else:
+            runGUI()
+
+
+    def runStartup(nocrc=False):
+        if appname != "":
+            logMessage(appname + " version " + appversion)
+        logMessage("Python", sys.version)
+        from . import __version__
+        logMessage("hacktools version", __version__)
+        if filecheck != "" and not os.path.isfile(filecheck):
+            logError(filecheck, "file not found.")
+            return False
+        if crc >= 0 and not nocrc:
+            checkcrc = crcFile(filecheck)
+            if crc != checkcrc:
+                logMessage("Checksum mismatch for", filecheck, "(" + toHex(checkcrc) + ", expected", toHex(crc) + ")")
+                logMessage("The tool might still work but you should run it on a good dump of the game.")
+        return True
+
+
+    def runCLI():
+        if not runStartup():
+            quit()
+        if len(sys.argv) > 1:
+            cli()
+            return
+        with click.Context(cli) as ctx:
+            click.echo(cli.get_help(ctx))
+            click.echo("")
+        while True:
+            cmd = click.prompt("Type a command").strip()
+            cmdlow = cmd.lower()
+            if cmdlow == "exit" or cmdlow == "quit" or cmdlow == "q":
+                break
+            sys.argv = shlex.split(sys.argv[0] + " " + cmd)
+            cli(standalone_mode=False)
+
+
+    def runGUI():
+        global hasGUI
+        hasGUI = True
+        from .gui import GUIApp
+        guiapp = GUIApp()
+        guiapp.initialize(cli, appname, appversion, datafolder)
+        guiapp.mainloop()
+
+
+# Logging
+class FileFilter(logging.Filter):
+    def filter(self, record):
+        return not record.getMessage().startswith("prg-")
+
+
+def setupFileLogging(log):
     logging.getLogger("PIL.PngImagePlugin").setLevel(logging.CRITICAL + 1)
-    logging.basicConfig(handlers=[logging.FileHandler(filename="tool.log", encoding="utf-8", mode="w")], format="[%(levelname)s] %(message)s", level=logging.DEBUG)
-
-
-def disableLogging():
-    logging.getLogger().disabled = True
+    filehandler = logging.FileHandler(filename="tool.log", encoding="utf-8", mode="w")
+    filehandler.addFilter(FileFilter())
+    logging.basicConfig(handlers=[filehandler], format="[%(levelname)s] %(message)s", level=logging.DEBUG if log else logging.INFO)
 
 
 def logMessage(*messages):
     message = " ".join(str(x) for x in messages)
     logging.info(message)
-    if hasTqdm:
+    if hasTqdm and sys.stdout is not None:
         tqdm.write(message)
 
 
@@ -416,13 +501,13 @@ def logDebug(*messages):
 
 def logWarning(*messages):
     message = " ".join(str(x) for x in messages)
-    logging.warning(message)
+    logging.debug("[WARNING]" + message)
 
 
 def logError(*messages):
     message = " ".join(str(x) for x in messages)
     logging.error(message)
-    if hasTqdm:
+    if hasTqdm and sys.stdout is not None:
         tqdm.write("[ERROR] " + message)
 
 
@@ -441,7 +526,11 @@ def varsHex(o):
 
 def showProgress(iterable):
     if hasTqdm:
-        return tqdm(iterable=iterable)
+        if hasGUI:
+            from .gui import tqdm_gui
+            return tqdm_gui(iterable=iterable)
+        else:
+            return tqdm(iterable=iterable)
     return iterable
 
 
@@ -597,9 +686,9 @@ def mergeSections(file1, file2, output, comment="#", fixchars=[]):
                     out.write(s + "\n")
                     continue
                 sectionstr = v["value"]
-                if sectionstr == '':
+                if sectionstr == "":
                     for section2 in sections2.keys():
-                        if s in sections2[section2] and sections2[section2][s][0] != '':
+                        if s in sections2[section2] and sections2[section2][s][0] != "":
                             sectionstr = sections2[section2][s][0]
                             break
                 out.write(s + "=" + sectionstr + "\n")
@@ -712,11 +801,11 @@ class TranslationFile:
             self._pretty_print(node, current, i, depth + 1)
         if parent is not None:
             if index == 0:
-                parent.text = '\n' + ('  ' * depth)
+                parent.text = "\n" + ("  " * depth)
             else:
-                parent[index - 1].tail = '\n' + ('  ' * depth)
+                parent[index - 1].tail = "\n" + ("  " * depth)
             if index == len(parent) - 1:
-                current.tail = '\n' + ('  ' * (depth - 1))
+                current.tail = "\n" + ("  " * (depth - 1))
 
 
 class FontGlyph:
@@ -1040,22 +1129,6 @@ def repackBinaryStrings(section, infile, outfile, binranges, freeranges=None, re
     return notfound
 
 
-def runCLI(command):
-    if len(sys.argv) > 1:
-        command()
-        return
-    with click.Context(command) as ctx:
-        click.echo(command.get_help(ctx))
-        click.echo("")
-    while True:
-        cmd = click.prompt('Type a command').strip()
-        cmdlow = cmd.lower()
-        if cmdlow == "exit" or cmdlow == "quit" or cmdlow == "q":
-            break
-        sys.argv = shlex.split(sys.argv[0] + " " + cmd)
-        command(standalone_mode=False)
-
-
 # Folders
 def makeFolder(folder, clear=True):
     if clear:
@@ -1074,7 +1147,8 @@ def copyFolder(f1, f2):
 
 
 def mergeFolder(f1, f2):
-    distutils.dir_util.copy_tree(f1, f2)
+    import distutils.dir_util
+    distutils.dir_util.copy_tree(f1, f2, verbose=0)
 
 
 def copyFile(f1, f2):
@@ -1122,10 +1196,10 @@ def bundledFile(name):
 
 
 def bundledExecutable(name):
-    if os.name != 'nt':
+    if os.name != "nt":
         name = name.replace(".exe", "")
     if os.path.isfile(name):
-        if os.name != 'nt':
+        if os.name != "nt":
             name = "./" + name
         return name
     try:
@@ -1137,7 +1211,7 @@ def bundledExecutable(name):
 def execute(cmd, show=True):
     result = ""
     try:
-        if os.name != 'nt':
+        if os.name != "nt":
             result = str(subprocess.check_output(shlex.split(cmd)))
         else:
             result = str(subprocess.check_output(cmd))
@@ -1159,7 +1233,7 @@ def execute(cmd, show=True):
 
 
 def crcFile(f):
-    buffersize = 65536
+    buffersize = 0x10000
     crc = 0
     with open(f, "rb") as crcf:
         buffer = crcf.read(buffersize)
